summaryrefslogtreecommitdiff
path: root/xmloff/source/forms/elementimport.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'xmloff/source/forms/elementimport.cxx')
-rw-r--r--xmloff/source/forms/elementimport.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmloff/source/forms/elementimport.cxx b/xmloff/source/forms/elementimport.cxx
index c010b666e552..d917ea31b8c7 100644
--- a/xmloff/source/forms/elementimport.cxx
+++ b/xmloff/source/forms/elementimport.cxx
@@ -1342,7 +1342,7 @@ namespace xmloff
// we don't want say form url targets to be resolved
// using ResolveGraphicObjectURL
if ( 0 == _rLocalName.compareToAscii( s_pImageDataAttributeName ) )
- sAdjustedValue = m_rContext.getGlobalContext().ResolveGraphicObjectURL( _rValue, FALSE );
+ sAdjustedValue = m_rContext.getGlobalContext().ResolveGraphicObjectURL( _rValue, sal_False );
else
sAdjustedValue = m_rContext.getGlobalContext().GetAbsoluteReference( _rValue );
return OImagePositionImport::handleAttribute( _nNamespaceKey, _rLocalName, sAdjustedValue );
@@ -1518,7 +1518,7 @@ namespace xmloff
}
}
// additionally, we need to set the "RichText" property of our element to TRUE
// (the presence of the text:p is used as indicator for the value of the RichText property)
sal_Bool bHasRichTextProperty = sal_False;
if ( m_xInfo.is() )
@@ -1518,7 +1518,7 @@ namespace xmloff
}
}
- // additionally, we need to set the "RichText" property of our element to TRUE
+ // additionally, we need to set the "RichText" property of our element to sal_True
// (the presence of the text:p is used as indicator for the value of the RichText property)
sal_Bool bHasRichTextProperty = sal_False;